PDFService class
Utility for copying a Flutter asset PDF to a temporary file so that the native Android layer can read it from the file system.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPdfFileFromAssets(
String assetPath) → Future< File> -
Copies the asset at
assetPathto the device's temporary directory and returns the resulting File. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited