methodChannel property
The method channel used to communicate with the native plugin.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('zpl_plugin_package');
The method channel used to communicate with the native plugin.
@visibleForTesting
final methodChannel = const MethodChannel('zpl_plugin_package');