PrinterConnectionManager class
Listens to the printer connection status stream and keeps isConnected up-to-date.
Call startMonitoringConnection once after construction and stopMonitoringConnection (or dispose) when the object is no longer needed to release the underlying stream subscription.
Constructors
- PrinterConnectionManager(ZebraPrinterRepository _repository)
- Creates a PrinterConnectionManager backed by repository.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConnected → bool
-
Whether the printer is currently connected.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Alias for stopMonitoringConnection — call this in
dispose(). -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startMonitoringConnection(
) → void - Starts listening to the native connection status stream.
-
stopMonitoringConnection(
) → void - Cancels the stream subscription and releases resources.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited