FlutterZebraPluginPlatform class abstract
The interface that platform-specific implementations must implement.
Defaults to MethodChannelFlutterZebraPlugin.
- Inheritance
-
- Object
- PlatformInterface
- FlutterZebraPluginPlatform
- Implementers
Constructors
- FlutterZebraPluginPlatform()
- Constructs a FlutterZebraPluginPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> - Returns the host Android SDK version string.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterZebraPluginPlatform
-
The default instance used by FlutterZebraIntegration.
getter/setter pair